@@ -87,7 +87,7 @@ class WizataDSAPIClient:
             return pickle.loads(model_bytes)
         if isinstance(obj, Script):
             script_bytes = self.__request_process("GET", "script", {"script_id": str(obj.script_id)}, "pickle")
-            return pickle.loads(script_bytes)
+            return dill.loads(script_bytes)
         else:
             raise TypeError("Type not supported.")
 
